function y = dsp_echo(x,RD,RT,Fs,Tiir,bits,fhp,in)
% y = dsp_echo(x,RD,RT,Fs,Tiir,bits,fhp,in)
% calculate echo output, y, based on input, x
% analyzed and plots resulting data
% inputs:
% RD   -> (reverberation delay echos/second)
% RT   -> (reverberation time to -60 bB point)
% Fs   -> (samples/sec)
% Tiir -> Delay time for iir
% bits -> bits of samples (orig. part of hack -> bits = 32)
% fhp  -> figure handle plot
% in   -> subplot index for 2x2 subplot
% outputs:
% y    -> resulting echo vector from x input
% dsp_echo.m
% author: Nicholas Kottenstette
% date:   11/9/2004
  bits = 32;
  [m,n] = size(x);
  % Check if x is a vecor and will keep as a single column vector
  if (m > 1) & (n > 1)
    error('dsp_fft:invalid_input','x not a vector m = %d, n = %d\n"',m,n);
  elseif m < n
    x = x';
    [m,n] = size(x);
  end
  %cancel out any large dc drifts which will reek havoc with the long iir!
  u = mean(x);
  x = (x - u);
  y = x + iir(x,RD,RT,Fs,Tiir,32) + fir(x,RD,RT,Fs,Tiir,32);
  %avoid saturation
  y = y*(2/(max(y)-min(y)));
  %plot time response of echo signal
  t = [0:length(y)-1]*(1/Fs);
  figure(fhp);subplot(2,2,in);plot(t,y);grid;axis([0,max(t),-1,1]);
  xlabel('time (s)');ylabel('amp');title('Echo time response');
  %plot frequency response of signal
  spec_plot(y,Fs,fhp,'Echo spectrogram',in+1);
  %Calculate and generate an impulse response of filter
  d = [1;zeros(ceil(Fs*RT),1)];
  h = d + iir(d,RD,RT,Fs,Tiir,bits) + fir(d,RD,RT,Fs,Tiir,bits);
  t = [0:length(d)-1]*(1/Fs);
  figure(fhp);subplot(2,2,in+2);plot([0 RT],[0 -60],t,20*log10(abs(h)+.0001),'.');grid;
  axis([0,max(t),-60,0]);xlabel('time (s)');ylabel('H (dB)');
  title('Impulse Response');
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%iir calculation
function y = iir(x,RD,RT,Fs,Tiir,bits)
  if RT == 0
    y = 0*x;
    return;
  end
  if Tiir < RT
    dRT = RT-Tiir;
  else
    dRT = 0.001;
  end
  %Calculate iir coef a1
  G1 = -60*(Tiir/(RT+.001));
  g1 = 10^(G1/20);
  a1 = 10^((-3-G1/20)/(dRT*Fs));
  %a1 is going to be limited by precision of waveform
  precision = (1 - 2^-(bits-2));
  if a1 > precision
    a1 = precision;
  end
  %.160 sec + 1/Fs delay
  nd = ceil(Tiir*Fs) + 1;
  N = length(x);
  y = zeros(N,1);
  y(nd+1:N) = x(1:(N-nd));
  x = g1*y; %re-index x with delayed form
  %Start filtering y after 0's
  for n = (nd+1):N
    y(n) = x(n) + a1*y(n-1);
  end
  
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%modified fir (incorporate the direct output)
function y = fir(x,RD,RT,Fs,Tiir,bits)
  nrd = floor(Fs/RD);
  nub = min(Tiir,RT)*Fs;
  Nc = 0;
  sum = nrd;
  h(1,1) = 1;
  mp = -60/(RT+.001);
  y = 0*x;
  while (sum < nub) | (sum == 0)
    Nc = Nc + 1;
    h(Nc,1) = 10^(mp*Nc*nrd/(20*Fs)); 
    sum = sum + nrd;
  end
  if Nc == 0
    y = h(1,1)*x;
    return;
  end
  Noff = Nc*nrd;
  xp = [zeros(Noff,1);x];
  di = Noff - [1:Nc]*nrd;
  for n = 1:length(x)
    xpi = n + di;
    y(n,1) = h'*xp(xpi);
  end
