function [y,h,G] = dsp_eq(sG,x,N,Fs,fhp,in)
%[y,h,G] = dsp_eq(sG,x,N,Fs,fhp,in)
%inputs:
%sG  -> the gain values for each respective frequency bin in dB
%x   -> input vector to equalize using the h coeficients
%N   -> desired taps for linear phase fir filter
%fhp -> figure handel for ploting
%in  -> index from 0-3 for a 2x2 subplot region to plot frequency resp.
%outputs:
%y   -> equalized data
%h   -> eq. filter coefecients
%G   -> magnituded response points
%dsp_eq.m
%author: Nicholas Kottenstette
%date:   11/9/2004
  
%Technique design linear phase filter using frequency sampling
%choose coef. to be symetric with alpha equal to 0
%see p.633 Table 8.3 for details in Proakis
%Keep spacing the same if lower sampled file is equalized
  freq = (Fs/44100)*[200*2.^[0:6] 44100/2];
  f = 0;
  df = Fs/N;
  if floor(N/2) == (N/2)
    U = N/2 - 1;
  else
    U = (N-1)/2;
  end
  %l = k+1;
  l = 1;
  flag = true;
  G=zeros(1,U);
  for j = 1:length(freq)
    while f < freq(j)
      if flag == true
        sg = sG(j);
      else
        %sg = (sG(j) + sG(j-1))/2;
        sg = sG(j);
        flag = true;
      end
      G(l) = ((-1)^(l-1))*10^(sg/20);
      f = f+df;
      l = l+1;
    end
    if j > 2
      flag = false;
    end
  end
  h = zeros(1,N);
  for n = 0:N-1
    sum = 0;
    for k = 1:U
      sum = sum + G(k+1)*cos(2*pi*k*(n+0.5)/N);
    end
    h(n+1) = (1/N)*(G(1)+2.0*sum);
    %Apply a hamming window to min-ripples and keep reasonable aprox with
    %lower freq adjust.
    h(n+1) = (0.54 - 0.46*cos(2*pi*n/(N-1)))*h(n+1);
    %h(n+1) = (0.5 - 0.5*cos(2*pi*n/(N-1)))*h(n+1);
  end
  %Plot resulting filter fft-response based on lever settings
  H = dsp_fft(h,N*2^4);
  H = H(1:length(H)/2)';
  dfH = Fs/((N*2^4)-1);
  frH = [0:((N*2^4)-1)/2]*dfH;
  frG = [0:df:(Fs/2)-1];
  figure(fhp);subplot(2,2,in);plot(frH,20*log10(abs(H)),frG,20*log10(abs(G)),'.');grid;
  xlabel('freq (Hz)');ylabel('DFT (dB)');title('Eq. Filter Response');
  axis([0,Fs/2,-12,12]);
  %Implement equalizer filter:
  y = dsp_filter(h,x,N);
  %Plot resulting spectrogram
  spec_plot(y,Fs,fhp,'equalized spectrogram',in+1);
  
function y = dsp_filter(h,x,N)
  lx = length(x);
  x = [zeros(1,N-1) x zeros(1,N)];
  x1i = [0:-1:-(N/2)+1] + N;
  x2i = [-(N-1):1:-N/2] + N;
  h = h(1+[0:(N/2)-1])';
  y = zeros(1,lx+N-1);
  for n=1:(lx+N-1)
    x1 = x(n + x1i);
    x2 = x(n + x2i);
    y(n) = (x1+x2)*h;
  end
  y = y*(2/(max(y)-min(y)));
