% reverberation()
% Graphical interface for reverberation generator
% reverberation.m
% author:   Nicholas Kottenstette
% gui code: borrowed slider and button code from Robert Stevenson
% date:     11/10/2004

% Initialize figure
left=50;
bottom=300;
width=450;
height=400;
fh = figure('Position',[left bottom width height],...
	'Resize','off',...
	'NumberTitle','off',...
	'Name','Reverberation');
fhp = figure('Name','Reverberation Analysis');
pos = get(fhp,'Position');
set(fhp,'Position',[left+width+10 bottom pos(3:4)]);
set(fh,'CloseRequestFcn','windows_close();');
clf(fh);
clf(fhp);

f = [ 0 0 0 0 0 0 0 0 ];
RTmin=0;
RTmax=5;
RDlmin=log10(10);
RDlmax=log10(1000);
RD=10;
RT=1;
x=[0];
Fs=44100;
bits=16;
y=[0];

%%%%%%%%%%%%%% Control buttons %%%%%%%%%%%

but_load = uicontrol(fh,...
        'Style', 'push',...
	'String', 'Load',...
        'Position', [10 10 100 25],...
	'callback','[x,Fs,bits]=load_audio_file(fhp,1);');

but_process = uicontrol(fh,...
        'Style', 'push',...
	'String', 'Process',...
        'Position', [120 10 100 25],...
	'callback','y=dsp_echo(x,RD,RT,Fs,.160,32,fhp,2);');

but_play = uicontrol(fh,...
        'Style', 'push',...
	'String', 'Play',...
        'Position', [230 10 100 25],...
	'callback','eq_play(x,y,Fs,bits);');

but_save = uicontrol(fh,...
        'Style', 'push',...
	'String', 'Save',...
        'Position', [340 10 100 25],...
	'callback','save_audio(y,Fs,bits);');

%%%%%%%%%%%%%% Band logRD %%%%%%%%%%%

sli_band4 = uicontrol(fh,...
        'Style', 'slider',...
	'Min', RDlmin,...
 	'Max', RDlmax,...
	'Value', RDlmin,...
        'Position', [200 60 20 300],...
	'callback','RD = 10^get(sli_band4,''Value'');');
txt_band4_title = uicontrol(fh,...
	'BackgroundColor',[0 0 0],...
	'ForegroundColor',[1 1 1],...
	'HorizontalAlignment','center',...
	'Style','text',...
	'Pos',[175 370 50 20],...
	'String','log10(RD)');
txt_band4_lab1 = uicontrol(fh,...
	'BackgroundColor',[0 0 0],...
	'ForegroundColor',[1 1 1],...
	'HorizontalAlignment','right',...
	'Style','text',...
	'Pos',[170 70 30 20],...
	'String','1');
txt_band4_lab2 = uicontrol(fh,...
	'BackgroundColor',[0 0 0],...
	'ForegroundColor',[1 1 1],...
	'HorizontalAlignment','right',...
	'Style','text',...
	'Pos',[170 135 30 20],...
	'String',' 1.5');
txt_band4_lab3 = uicontrol(fh,...
	'BackgroundColor',[0 0 0],...
	'ForegroundColor',[1 1 1],...
	'HorizontalAlignment','right',...
	'Style','text',...
	'Pos',[170 200 30 20],...
	'String',' 2');
txt_band4_lab4 = uicontrol(fh,...
	'BackgroundColor',[0 0 0],...
	'ForegroundColor',[1 1 1],...
	'HorizontalAlignment','right',...
	'Style','text',...
	'Pos',[170 265 30 20],...
	'String',' 2.5');
txt_band4_lab5 = uicontrol(fh,...
	'BackgroundColor',[0 0 0],...
	'ForegroundColor',[1 1 1],...
	'HorizontalAlignment','right',...
	'Style','text',...
	'Pos',[170 330 30 20],...
	'String',' 3');

%%%%%%%%%%%%%% RT band %%%%%%%%%%%

sli_band5 = uicontrol(fh,...
        'Style', 'slider',...
	'Min', RTmin,...
 	'Max', RTmax,...
	'Value', RT,...
        'Position', [250 60 20 300],...
	'callback','RT=get(sli_band5,''Value'');');
txt_band5_title = uicontrol(fh,...
	'BackgroundColor',[0 0 0],...
	'ForegroundColor',[1 1 1],...
	'HorizontalAlignment','center',...
	'Style','text',...
	'Pos',[225 370 50 20],...
	'String','RT');
txt_band5_lab1 = uicontrol(fh,...
	'BackgroundColor',[0 0 0],...
	'ForegroundColor',[1 1 1],...
	'HorizontalAlignment','right',...
	'Style','text',...
	'Pos',[220 70 30 20],...
	'String','0');
txt_band5_lab2 = uicontrol(fh,...
	'BackgroundColor',[0 0 0],...
	'ForegroundColor',[1 1 1],...
	'HorizontalAlignment','right',...
	'Style','text',...
	'Pos',[220 135 30 20],...
	'String',' 1.25');
txt_band5_lab3 = uicontrol(fh,...
	'BackgroundColor',[0 0 0],...
	'ForegroundColor',[1 1 1],...
	'HorizontalAlignment','right',...
	'Style','text',...
	'Pos',[220 200 30 20],...
	'String','  2.5');
txt_band5_lab4 = uicontrol(fh,...
	'BackgroundColor',[0 0 0],...
	'ForegroundColor',[1 1 1],...
	'HorizontalAlignment','right',...
	'Style','text',...
	'Pos',[220 265 30 20],...
	'String',' 3.75');
txt_band5_lab5 = uicontrol(fh,...
	'BackgroundColor',[0 0 0],...
	'ForegroundColor',[1 1 1],...
	'HorizontalAlignment','right',...
	'Style','text',...
	'Pos',[220 330 30 20],...
	'String','5');

  